﻿using System.Collections.ObjectModel;
using System.ComponentModel;
using System.Windows;
using System.Collections.Generic;

namespace XamOutLookBarTest
{
	/// <summary>
	/// Interaction logic for MainWindow.xaml
	/// </summary>
	public partial class MainWindow : Window
	{
		private ObservableCollection<TempSessionModel> _sessionSource;
		public ObservableCollection<TempSessionModel> SessionSource
		{
			get
			{
				if (null == _sessionSource)
				{
					_sessionSource = new ObservableCollection<TempSessionModel>();
				}
				return _sessionSource;
			}
		}

		public MainWindow()
		{
			InitializeComponent();
			TempSessionViewModel vm1 = new TempSessionViewModel() { Source = GetData1() };			
			SessionSource.Add(new TempSessionModel() { Name = "Session1", ViewModel = vm1 });


			TempSessionViewModel vm2 = new TempSessionViewModel() { Source = GetData2() };
			SessionSource.Add(new TempSessionModel() { Name = "Session2", ViewModel = vm2 });
			
		}

		private ObservableCollection<Department> GetData1()
		{
			ObservableCollection<Department> taskGroups = new ObservableCollection<Department>();

			Department d1 = new Department();
			d1.GroupName = "Group1";
			d1.GroupId = "1";			
			d1.Employees.Add(new Employee(){EmployeeName = "Emp1"});
			d1.Employees.Add(new Employee() { EmployeeName = "Emp2" });
			d1.IsSelected = true;

			Department d2 = new Department();
			d2.GroupName = "Group2";
			d2.GroupId = "2";
			d2.Employees.Add(new Employee() { EmployeeName = "Emp3" });
			d2.Employees.Add(new Employee() { EmployeeName = "Emp4" });

			taskGroups.Add(d1);
			taskGroups.Add(d2);

			return taskGroups;

		}

		private ObservableCollection<Department> GetData2()
		{
			ObservableCollection<Department> taskGroups = new ObservableCollection<Department>();

			Department d3 = new Department();
			d3.GroupName = "Group3";
			d3.GroupId = "3";			
			d3.Employees.Add(new Employee() { EmployeeName = "Emp5" });
			d3.Employees.Add(new Employee() { EmployeeName = "Emp6" });

			Department d4 = new Department();
			d4.GroupName = "Group4";
			d4.GroupId = "4";
			d4.Employees.Add(new Employee() { EmployeeName = "Emp7" });
			d4.Employees.Add(new Employee() { EmployeeName = "Emp8" });

			taskGroups.Add(d3);
			taskGroups.Add(d4);

			return taskGroups;

		}

		private void Button_Click(object sender, RoutedEventArgs e)
		{
			if (!SessionSource[0].ViewModel.Source[0].IsSelected)
			{
				SessionSource[0].ViewModel.Source[0].IsSelected = true;	
			}
			else
			{
				SessionSource[0].ViewModel.Source[1].IsSelected = true;
			}
			
		}
	}

	public class TempSessionModel
	{
		public string Name { get; set; }

		public TempSessionViewModel ViewModel { get; set; }
	}

	public class TempSessionViewModel : INotifyPropertyChanged
	{
		private Department _selectedGroupTarget;
		public Department SelectedTarget
		{
			get { return _selectedGroupTarget; }
			set
			{
				_selectedGroupTarget = value;
				OnPropertyChange("SelectedTarget");
			}
		}

		public ObservableCollection<Department> Source { get; set; }		

		#region INotifyPropertyChanged Members

		public event PropertyChangedEventHandler PropertyChanged;

		private void OnPropertyChange(string name)
		{
			if (null != PropertyChanged)
			{
				PropertyChanged(this, new PropertyChangedEventArgs(name));
			}
		}

		#endregion
	}	

	public class Department : INotifyPropertyChanged
	{
		#region Data

		private bool _isSelected;
		public bool IsSelected
		{
			get { return _isSelected; }
			set
			{
				_isSelected = value;
				OnPropertyChange("IsSelected");
			}
		}

		private string _groupName;
		public string GroupName
		{
			get { return _groupName; }
			set { _groupName = value; }
		}

		private string _groupId;
		public string GroupId
		{
			get { return _groupId; }
			set 
			{ 
				_groupId = value;
				OnPropertyChange("GroupId");
			}
		}


		private IList<Employee> _employees;
		public IList<Employee> Employees
		{
			get 
			{
				if (null == _employees )
				{
					_employees = new List<Employee>();
				}
				return _employees; 
			}
		}

		private Employee _selectedTarget;
		public Employee SelectedTarget 
		{
			get { return _selectedTarget; }
			set 
			{
				_selectedTarget = value;
				OnPropertyChange("SelectedTarget");
			}
		}

		#endregion

		#region INotifyPropertyChanged Members

		public event PropertyChangedEventHandler PropertyChanged;

		private void OnPropertyChange(string name)
		{
			if (null != PropertyChanged)
			{
				PropertyChanged(this, new PropertyChangedEventArgs(name));
			}
		}

		#endregion
	}

	public class Employee : INotifyPropertyChanged
	{
		#region Data

		private bool _isSelected;
		public bool IsSelected
		{
			get { return _isSelected; }
			set
			{
				_isSelected = value;
				OnPropertyChange("IsSelected");
			}
		}

		private string _employeeName;
		public string EmployeeName
		{
			get { return _employeeName; }
			set { _employeeName = value; }
		}

		private ObservableCollection<Employee> _employees;
		public ObservableCollection<Employee> Employees
		{
			get { return _employees; }
			set { _employees = value; }
		}

		#endregion

		#region INotifyPropertyChanged Members

		public event PropertyChangedEventHandler PropertyChanged;

		private void OnPropertyChange(string name)
		{
			if (null != PropertyChanged)
			{
				PropertyChanged(this, new PropertyChangedEventArgs(name));
			}
		}

		#endregion
	}
}
