﻿using System.Collections.ObjectModel;
using System.Linq;
using System.Windows;
using System.Windows.Controls;
using System.Windows.Input;

namespace XamOutLookBarTest
{
	/// <summary>
	/// Interaction logic for NavigationControl.xaml
	/// </summary>
	public partial class NavigationControl : UserControl
	{
		#region Constructors

		public NavigationControl()
		{
			InitializeComponent();
			this.DataContextChanged += new DependencyPropertyChangedEventHandler(NavigationControl_DataContextChanged);
		}

		void NavigationControl_DataContextChanged(object sender, DependencyPropertyChangedEventArgs e)
		{
						
		}

		#endregion

		#region Properties

		public ObservableCollection<Department> Targets
		{
			get { return (ObservableCollection<Department>)GetValue(TargetsProperty); }
			set { SetValue(TargetsProperty, value); }
		}

		// Using a DependencyProperty as the backing store for Targets.  This enables animation, styling, binding, etc...
		public static readonly DependencyProperty TargetsProperty =
			DependencyProperty.Register("Targets", typeof(ObservableCollection<Department>), typeof(NavigationControl),
			new PropertyMetadata(null, OnTargetsChangedCallback));



		public Department SelectedGroupTarget
		{
			get { return (Department)GetValue(SelectedGroupTargetProperty); }
			set { SetValue(SelectedGroupTargetProperty, value); }
		}

		// Using a DependencyProperty as the backing store for SelectedGroupTarget.  This enables animation, styling, binding, etc...
		public static readonly DependencyProperty SelectedGroupTargetProperty =
			DependencyProperty.Register("SelectedGroupTarget", typeof(Department), typeof(NavigationControl));




		public DataTemplateSelector SelectedGroupTemplateSelector
		{
			get { return (DataTemplateSelector)GetValue(SelectedGroupTemplateSelectorProperty); }
			set { SetValue(SelectedGroupTemplateSelectorProperty, value); }
		}

		// Using a DependencyProperty as the backing store for SelectedGroupTemplateSelector.  This enables animation, styling, binding, etc...
		public static readonly DependencyProperty SelectedGroupTemplateSelectorProperty =
			DependencyProperty.Register("SelectedGroupTemplateSelector", typeof(DataTemplateSelector), typeof(NavigationControl));


		
		#endregion

		#region Private Methods
		/// <summary>
		/// Handler for Targets property changed callback.
		/// </summary>
		/// <param name="d"></param>
		/// <param name="e"></param>
		private static void OnTargetsChangedCallback(DependencyObject d, DependencyPropertyChangedEventArgs e)
		{
			NavigationControl control = d as NavigationControl;
			if (null != control && null != e)
			{
				ObservableCollection<Department> targets = e.NewValue as ObservableCollection<Department>;
				control.SetSelected(targets);				
			}
		}

		/// <summary>
		/// 
		/// </summary>
		/// <param name="targets"></param>
		public void SetSelected(ObservableCollection<Department> targets)
		{
			if (null != targets && targets.Count > 0)
			{
				//if (null == SelectedGroupTarget)
				{
					//Get the selected grouptarget if any
					var selectedGroupTarget = (from item in targets
											   where (item.IsSelected)
											   select item).FirstOrDefault<Department>();

					//Comment when using binding between XamOutlookBar's SelectedGroup and SelectedGroupTarget. Changes will have to be made in the XAML too
					//to set the binding
					if (null == selectedGroupTarget)
					{
						targets[0].IsSelected = true;
					}


					////UnComment when using SelectedGroup for binding
					////If no such grouptarget is found, set  then first group with selected target set
					//if (null == selectedGroupTarget)
					//{
					//    //Get the group that has a selected target if any
					//    selectedGroupTarget = (from item in targets
					//                           where (null != item.SelectedTarget)
					//                           select item).FirstOrDefault<Department>();

					//    //If no group with set target is found, set the first group with as selected target
					//    if (null == selectedGroupTarget)
					//    {
					//        selectedGroupTarget = targets[0];
					//    }
					//}

					//if (null == selectedGroupTarget.SelectedTarget)
					//{
					//    selectedGroupTarget.SelectedTarget = selectedGroupTarget.Employees[0];
					//}

					//selectedGroupTarget.IsSelected = true;
					//SelectedGroupTarget = selectedGroupTarget;
				}				
			}
		}		

		#endregion

		#region Event

		private void OutlookBar_MouseLeftButtonDown(object sender, MouseButtonEventArgs e)
		{ }


		private void TreeView_MouseLeftButtonDown(object sender, MouseButtonEventArgs e)
		{ }
		#endregion
	}
}
