﻿using System;
using System.Globalization;
using System.Windows.Data;
using Infragistics.Windows.OutlookBar;

namespace XamOutLookBarTest
{
	/// <summary>
	/// Class to convert selected navigation target to outlookbargroup and vice versa.
	/// </summary>
	[ValueConversion(typeof(Department), typeof(OutlookBarGroup))]
	internal class NavigationTargetToOutlookGroupConverter : IValueConverter
	{
		#region IValueConverter Members

		/// <summary>
		/// Converts data from source to target
		/// </summary>
		/// <param name="value">The value to be converted</param>
		/// <param name="targetType">The target type</param>
		/// <param name="parameter">Teh parameter passed while binding</param>
		/// <param name="culture">Culture info</param>
		/// <returns>Returns null if cannot convert else OutlookBarGroup</returns>
		public object Convert(object value, Type targetType, object parameter, CultureInfo culture)
		{
			OutlookBarGroup selectedGroup = null;
			if (null != value)
			{
				Department target = value as Department;
				if (null != targetType)
				{
					selectedGroup = new OutlookBarGroup();
					selectedGroup.DataContext = target;
				}
			}

			return selectedGroup;
		}

		/// <summary>
		/// Converts data back from target to source
		/// </summary>
		/// <param name="value">The value to be converted</param>
		/// <param name="targetType">The target type</param>
		/// <param name="parameter">Teh parameter passed while binding</param>
		/// <param name="culture">Culture info</param>
		/// <returns>Returns null if cannot convert else NavigationGroupTarget</returns>
		public object ConvertBack(object value, Type targetType, object parameter, CultureInfo culture)
		{
			Department selectedTarget = null;
			if (null != value)
			{
				OutlookBarGroup group = value as OutlookBarGroup;
				if (null != group)
				{
					Department target = group.DataContext as Department;
					if (null != target)
					{
						selectedTarget = target;
					}
				}
			}

			return selectedTarget;
		}

		#endregion
	}
}